<template>
  <div>
    <div class="tree_data_box">
      <el-form
        ref="form"
        :model="newRowData"
        :rules="rules"
        label-width="80px"
        size="mini"
      >
        <el-form-item label="模板名称" prop="id">
          <el-input v-model.trim="newRowData.id" :disabled="!disabledBtn" :maxLength="20" clearable/>
        </el-form-item>
        <el-form-item label="标签" prop="name">
          <el-input v-model.trim="newRowData.name" :disabled="!disabledBtn" clearable/>
        </el-form-item>
        <el-form-item label="起始状态" prop="startStatus">
          <el-select
            v-model="newRowData.startStatus"
            :disabled="!disabledBtn"
            placeholder="请选择起始状态"
            style="width: 100%"
          >
            <el-option
              v-for="item in existNodes"
              :key="item.id"
              :label="item.id"
              :value="item.id"
            >
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="描述">
          <el-input v-model.trim="newRowData.description" :disabled="!disabledBtn" type="textarea"></el-input>
        </el-form-item>
      </el-form>
    </div>
    <detail-panel>
      <template v-slot="{ status }">
        <node-panel :status="status">
          <detail-form ref="detailFrom" type="node"/>
        </node-panel>
        <edge-panel :status="status">
          <detail-form type="edge"/>
        </edge-panel>
        <group-panel :status="status">
          <detail-form type="group"/>
        </group-panel>

        <div v-if="status === 'edge-selected'" class="event">
          <hr/>
          <h4>跃迁事件</h4>
          <el-select
            ref="mySelect"
            v-model="currentSelectedLine.events"
            :disabled="!disabledBtn"
            multiple
            size="mini"
            style="width: 100%"
            value-key="oid"
            @change="handleChange"
          >
            <el-option
              v-for="(item,index) in newRowData.eventList"
              :key="index"
              :label="item"
              :value="item"
            ></el-option>
          </el-select>
        </div>
      </template>
    </detail-panel>
  </div>
</template>

<script>
// import API from "@/api/modeling/cycle";

import {
  NodePanel,
  EdgePanel,
  GroupPanel,
  MultiPanel,
  CanvasPanel,
  DetailPanel,
} from "vue-flowchart-editor";
import DetailForm from "./DetailForm";

export default {
  name: "EditorDetailPanel",
  components: {
    NodePanel,
    EdgePanel,
    GroupPanel,
    MultiPanel,
    CanvasPanel,
    DetailPanel,
    DetailForm,
  },
  props: ["rowData", "existNodes", "existEdges", "type", "currentSelectedLine"],
  data() {
    return {
      newRowData: {
        startStatus: undefined,
        name: undefined,
        id: undefined,
        remark: undefined,
        saveEventList: []
      },
      rules: {
        name: [{required: true, message: "标签不能为空", trigger: "blur"}],
        id: [
          {required: true, message: "名称不能为空", trigger: "blur"},
          {
            pattern: /^[A-z]+$/g,
            message: "标签只能输入英文",
            trigger: "blur",
          },
        ],
        startStatus: [
          {required: true, message: "起始状态不能为空", trigger: "change"},
        ],
      },
      eventList: [
        {
          oid: '1',
          value: 'xxx',
          eventShowName: 'xxx'
        }
      ],
      edgeEventList: {},
      currentActive: 0,
    };
  },
  created() {
  },
  computed: {
    disabledBtn() {
      return this.$store.state.flow.methodBtn;
    }
  },
  methods: {
    async getNewRowDate() {
      return new Promise((resolve) => {
        this.$refs.form.validate((flag) => {
          if (!flag) {
            resolve(false);
          } else {
            resolve(this.newRowData);
          }
        });
      });
    },
    handleChange(val) {
    }

  },
  watch: {
    rowData: {
      deep: true,
      immediate: true,
      handler(newV) {
        if (
          typeof newV === "object" &&
          newV !== null &&
          Object.keys(this.rowData).length > 0
        ) {
          this.newRowData = Object.assign({}, newV);
        }
      },
    },
    existNodes(newV) {
      const flag = newV.some((item) => item.id === this.newRowData.startStatus);
      if (!flag) {
        this.newRowData.startStatus = undefined;
      }
    },
  },
};
</script>
<style lang="scss" scoped>

::v-deep {
  .el-tag.el-tag--info {
    color: #409eff;
    background-color: #ecf5ff;
  }
}

.event {
  margin-top: 20px;
  text-align: center;
}

.flex {
  margin-top: 10px;
  display: flex;
  justify-content: space-between;
}

.red {
  color: red;
}

.active {
  // box-shadow: 2px 2px 2px rgba(0, 0, 0, 0.4)
}
</style>
